# Security Policy

## Supported Versions

Versions of laskea currently being supported with security updates.

| Version     | Supported          |
| ----------- | ------------------ |
| 2022.5.31   | :white_check_mark: |
| 2022.4.30   | :white_check_mark: |
| < 2022.4.30 | :x:                |

## Reporting a Vulnerability

Please contact the maintainer per stefan@hagen.link
